@@ -318,7 +318,7 @@ async def nes_sync_task(ctx: ZeldaContext):
                     if not ctx.auth:
                         ctx.auth = ''.join([chr(i) for i in data_decoded['playerName'] if i != 0])
                         if ctx.auth == '':
-                            logger.info("Invalid ROM detected. No player name built into the ROM. Please regenerate"
+                            logger.info("Invalid ROM detected. No player name built into the ROM. Please regenerate "
                                         "the ROM using the same link but adding your slot name")
                         if ctx.awaiting_rom:
                             await ctx.server_auth(False)
@@ -368,7 +368,7 @@ async def nes_sync_task(ctx: ZeldaContext):
                 continue
 
 
-def launch(server_address, password, slot_name, ready_callback, error_callback, patch_file):
+def launch(server_address, password, ready_callback, error_callback, patch_file):
     # Text Mode to use !hint and such with games that have no text entry
     Utils.init_logging("ZeldaClient")
 
